> Author : Zhihui Li
>
> E-mail：[18210700119@fudan.edu.cn](mailto:18210700119@fudan.edu.cn)
>
> Git: <http://choppy.3steps.cn/lizhihui/trimmomatic.git>
>
> Last Updates: 28/08/2019

## 简介

Trimmomatic 是一个广受欢迎的 Illumina 平台数据过滤工具。NGS 原始数据过滤对后续分析至关重要，去除一些无用的序列也可以提高后续分析的准确率和效率。`trimmomatic`是用于 [Choppy-pipe](http://choppy.3steps.cn/) 系统使用的 APP。

## 快速安装及使用

#### Requirements

- Python 3
- [choppy](http://choppy.3steps.cn/)
- Ali-Cloud

在终端中输入以下命令即可快速安装本APP。

```bash
1.安装
$ source activate choppy-py3
$ choppy install lizhihui/trimmomatic
$ choppy apps
2.使用
$ choppy samples trimmomatic --out Projectname_trimmomatic_date_people.csv
$ choppy batch trimmomatic Projectname_trimmomatic_date_people.csv --project-name Projectname_trimmomatic_date_people
```

## 使用方法

### 任务的准备

按照上述步骤安装成功之后，可以通过下面简单的命令即可使用APP：

```bash
# Generate samples file
$ choppy samples trimmomatic --out Projectname_trimmomatic_date_people.csv
```

`Projectname_trimmomatic_date_people.csv` 包含以下几个需要填写的参数：

- 文件中必须包含的列为：
  - sample_id：样本名称，该名称将自动作为生成结果文件的前缀名
  - read1：原始FASTQ文件所在的OSS路径（仅R1）
  - read2：原始FASTQ文件所在的OSS路径（仅R2）
  - baseout：样本名称，该名称将自动作为生成结果文件的前缀名
  - disk_size：任务运行时，集群存储空间设置（一般设置为合并文件之和的5倍即可）

```bash
read1,read2,sample_id,baseout,disk_size
# read1  		双端测序数据的R1端在阿里云上的路径信息
# read2  		双端测序数据的R2端在阿里云上的路径信息
# sample_id 样本名称，该名称将自动作为生成结果文件的前缀名
# baseout		每个样本任务的识别码。
# disk_size	任务运行时，集群存储空间设置
```

### 任务提交

在配置好`trimmomatic Projectname_trimmomatic_date_people.csv` 文件后，使用以下命令可以提交计算任务：

```bash
$ choppy batch trimmomatic Projectname_trimmomatic_date_people.csv --project-name Projectname_trimmomatic_date_people
```

提交成功后，即可在工作目录下找到生成的目录名为Projectname_trimmomatic_date_people，里面包含了本次提交任务的所有样本信息。

### 任务输出

任务成功结束后，便可以在阿里云相应的OSS端生成相应的结果文件。包括数据去接头及低质量碱基所产生去接头`fastq`文件。

## APP流程概述

Trimmomatic 过滤数据的步骤与命令行中过滤参数的顺序有关，通常的过滤步骤如下：

![img](http://image109.360doc.com/DownloadImg/2018/04/2316/131021335_1_20180423042350441.png)

  - ILLUMINACLIP: 过滤 reads 中的 Illumina 测序接头和引物序列，并决定是否去除反向互补的 R1/R2 中的 R2。
  - SLIDINGWINDOW: 从 reads 的 5’ 端开始，进行滑窗质量过滤，切掉碱基质量平均值低于阈值的滑窗。
  - MAXINFO: 一个自动调整的过滤选项，在保证 reads 长度的情况下尽量降低测序错误率，最大化 reads 的使用价值。
  - LEADING: 从 reads 的开头切除质量值低于阈值的碱基。
  - TRAILING: 从 reads 的末尾开始切除质量值低于阈值的碱基。
  - CROP: 从 reads 的末尾切掉部分碱基使得 reads 达到指定长度。
  - HEADCROP: 从 reads 的开头切掉指定数量的碱基。
  - MINLEN: 如果经过剪切后 reads 的长度低于阈值则丢弃这条 reads。
  - AVGQUAL: 如果 reads 的平均碱基质量值低于阈值则丢弃这条 reads。
  - TOPHRED33: 将 reads 的碱基质量值体系转为 phred-33。
  - TOPHRED64: 将 reads 的碱基质量值体系转为 phred-64。

## 输出文件说明

运行APP后，

每个sample对应一个文件夹，内部结构如下：

- call-trimmomatic

  - glob-****/
  	- <sample_id>_1P.fq.gz 原始FASTQ文件在去接头及低质量碱基后产生的FASTQ文件（仅R1）
  	- <sample_id>_1U.fq.gz 原始FASTQ文件所去接头及低质量碱基的FASTQ文件（仅R1）
  	- <sample_id>_2P.fq.gz 原始FASTQ文件在去接头及低质量碱基后产生的FASTQ文件（仅R2）
  	- <sample_id>_2U.fq.gz 原始FASTQ文件所去接头及低质量碱基的FASTQ文件（仅R2）





## 软件版本及参数

###软件版本

trimmomatic: v0.38



### 使用参数

1.ILLUMINACLIP: 过滤 reads 中的 Illumina 测序接头和引物序列

2.TOPHRED33: 将 reads 的碱基质量值体系转为 phred-33。

3.adapter:

TruSeq3-PE.fa

>PrefixPE/1
>TACACTCTTTCCCTACACGACGCTCTTCCGATCT
>PrefixPE/2
>GTGACTGGAGTTCAGACGTGTGCTCTTCCGATCT

4.cluster: OnDemand bcs.a2.xlarge img-ubuntu-vpc





## 参考文献

[1]Bolger A M , Lohse M , Usadel B . Trimmomatic: a flexible trimmer for Illumina sequence data[J]. Bioinformatics, 2014, 30(15):2114-2120.

[2] http://www.360doc.com/content/18/0423/16/54810519_748099048.shtml